==> policy-highlights-1.1.0.tgz: package/README.md <==
<p align="center">
  <img width="550px" height="450px" src="./static/readme.png">
</p>

<h1 align="center">Policy Highlights</h1>

<p align="center">Automatically highlight keywords on your privacy policy, cookie policy, disclosure policy, disclaimer policy, and terms of service so the user can quickly find and understand important sections.</p>

<p align="center">
  <a aria-label="npm package" href="https://www.npmjs.com/package/@weareprivacy/policy-highlights">
    <img alt="" src="https://img.shields.io/npm/v/@weareprivacy/policy-highlights.svg">
  </a>
  <a aria-label="contributors graph" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/graphs/contributors">
    <img src="https://img.shields.io/github/contributors/weareprivacy/weareprivacy-policy-highlights.svg">
  </a>
  <a aria-label="last commit" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/commits/master">
    <img alt="" src="https://img.shields.io/github/last-commit/weareprivacy/weareprivacy-policy-highlights.svg">
  </a>
  <a aria-label="license" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/blob/master/LICENSE.txt">
    <img src="https://img.shields.io/github/license/weareprivacy/weareprivacy-policy-highlights.svg" alt="">
  </a>
</p>

## Usage

### General Usage

Include the script in your website privacy policy right before the `</body>` tag.

Policy highlights can be served from a CDN such as [JSDelivr](https://www.jsdelivr.com) or [Unpkg](https://unpkg.com). Simply use the `simple-icons` npm package and specify a version in the URL like the following:

```html
<script src="https://cdn.jsdelivr.net/npm/@weareprivacy/policy-highlights" type="text/javascript"></script>
<script src="https://unpkg.com/@weareprivacy/policy-highlights" type="text/javascript"></script>
```

## Example

See `dist/index.html`

## Development
See [DEVELOP.md](./DEVELOP.md) for development docs.

## License

[MIT](./LICENSE.txt) &copy; [GitHub](https://github.com/)

==> policy-highlights-1.6.0.tgz: package/README.md <==
<p align="center">
  <img width="550px" height="450px" src="./static/readme.png">
</p>

<h1 align="center">Policy Highlights</h1>

<p align="center">Automatically highlight keywords on your privacy policy, cookie policy, disclosure policy, disclaimer policy, and terms of service so the user can quickly find and understand important sections.</p>

<p align="center">
  <a aria-label="npm package" href="https://www.npmjs.com/package/@weareprivacy/policy-highlights">
    <img alt="" src="https://img.shields.io/npm/v/@weareprivacy/policy-highlights.svg">
  </a>
  <a aria-label="contributors graph" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/graphs/contributors">
    <img src="https://img.shields.io/github/contributors/weareprivacy/weareprivacy-policy-highlights.svg">
  </a>
  <a aria-label="last commit" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/commits/master">
    <img alt="" src="https://img.shields.io/github/last-commit/weareprivacy/weareprivacy-policy-highlights.svg">
  </a>
  <a aria-label="license" href="https://github.com/weareprivacy/weareprivacy-policy-highlights/blob/master/LICENSE.txt">
    <img src="https://img.shields.io/github/license/weareprivacy/weareprivacy-policy-highlights.svg" alt="">
  </a>
</p>

## Usage

### General Usage

Include the script in your website policy page right before the `</body>` tag.

Policy highlights can be served from a CDN such as [JSDelivr](https://www.jsdelivr.com) or [Unpkg](https://unpkg.com). Simply use the `@weareprivacy/policy-highlights` npm package:

```html
<script src="https://cdn.jsdelivr.net/npm/@weareprivacy/policy-highlights" type="text/javascript"></script>
<script src="https://unpkg.com/@weareprivacy/policy-highlights" type="text/javascript"></script>
```

## Example

See `dist/index.html`

## Development
See [DEVELOP.md](./DEVELOP.md) for development docs.

## License

[MIT](./LICENSE.txt) &copy; [GitHub](https://github.com/)
